<h1 align="center">
  Openlist-Ani
</h1>
<p align="center">
  从动漫番剧相关的RSS订阅源中自动获取番剧更新并通过Openlist离线下载至对应网盘
</p>  
<p align="center">
  并结合使用LLM分析资源名，将资源重命名为Emby可解析的格式。
</p>  

--- 

[使用文档](https://github.com/TwooSix/Alist-MikananiRss/wiki/%E5%BF%AB%E9%80%9F%E5%BC%80%E5%A7%8B)
## 特点
- 自动获取番剧更新并下载至对应网盘
- 通过PushPlus, Telegram等渠道发送更新通知
- 支持PikPak, 115等离线下载
- AI自主分析资源名，并结合搜索TMDB数据库，获取准确的番剧名，季度，集数来实现重命名
- 拥有你的AI智能下载助手，可挂载到telegrambot上，通过自然语言的方式让ai帮你搜索并下载资源

## 准备工作 
1. 请自行参照[Openlist](https://doc.oplist.org/guide)项目文档部署Openlist，并搭建好离线下载
2. 准备好RSS订阅连接

## 如何使用
参考[快速开始](https://github.com/TwooSix/Openlist-Ani/wiki/%E5%BF%AB%E9%80%9F%E5%BC%80%E5%A7%8B)


## 效果展示
| 重命名结果 | 智能助理 |
| :---: | :---: |
| <img src="https://github.com/TwooSix/Openlist-Ani/blob/master/imgs/show_pic1.png" width="400"/> | <img src="https://github.com/TwooSix/Openlist-Ani/blob/master/imgs/show_pic2.jpg" width="150"/> |
